# Installation & Setup Guide
### Via PyPI
Execute:
```
pip install XXX_set_package_name_XXX
```

### Via GitHub (`uv`)
To install in development mode, we recommend using uv.

1) Install uv from the [Astral website](https://docs.astral.sh/uv/getting-started/installation/), or install via PyPI with `pip install uv`

2) Clone the XXX_set_package_name_XXX repo:
```
git clone https://github.com/SETT-Centre-Data-and-AI/XXX_set_package_name_XXX.git
```

3) Navigate to the repositry (`cd ...\XXX_set_package_name_XXX\`) and execute:
```
uv sync --group dev
```
